/*
 * Copyright 2022 The Furiko Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/furiko-io/furiko/apis/execution/v1alpha1"
	scheme "github.com/furiko-io/furiko/pkg/generated/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// JobConfigsGetter has a method to return a JobConfigInterface.
// A group's client should implement this interface.
type JobConfigsGetter interface {
	JobConfigs(namespace string) JobConfigInterface
}

// JobConfigInterface has methods to work with JobConfig resources.
type JobConfigInterface interface {
	Create(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.CreateOptions) (*v1alpha1.JobConfig, error)
	Update(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.UpdateOptions) (*v1alpha1.JobConfig, error)
	UpdateStatus(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.UpdateOptions) (*v1alpha1.JobConfig, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.JobConfig, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.JobConfigList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.JobConfig, err error)
	JobConfigExpansion
}

// jobConfigs implements JobConfigInterface
type jobConfigs struct {
	client rest.Interface
	ns     string
}

// newJobConfigs returns a JobConfigs
func newJobConfigs(c *ExecutionV1alpha1Client, namespace string) *jobConfigs {
	return &jobConfigs{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the jobConfig, and returns the corresponding jobConfig object, and an error if there is any.
func (c *jobConfigs) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.JobConfig, err error) {
	result = &v1alpha1.JobConfig{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("jobconfigs").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of JobConfigs that match those selectors.
func (c *jobConfigs) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.JobConfigList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.JobConfigList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("jobconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested jobConfigs.
func (c *jobConfigs) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("jobconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a jobConfig and creates it.  Returns the server's representation of the jobConfig, and an error, if there is any.
func (c *jobConfigs) Create(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.CreateOptions) (result *v1alpha1.JobConfig, err error) {
	result = &v1alpha1.JobConfig{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("jobconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(jobConfig).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a jobConfig and updates it. Returns the server's representation of the jobConfig, and an error, if there is any.
func (c *jobConfigs) Update(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.UpdateOptions) (result *v1alpha1.JobConfig, err error) {
	result = &v1alpha1.JobConfig{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("jobconfigs").
		Name(jobConfig.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(jobConfig).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *jobConfigs) UpdateStatus(ctx context.Context, jobConfig *v1alpha1.JobConfig, opts v1.UpdateOptions) (result *v1alpha1.JobConfig, err error) {
	result = &v1alpha1.JobConfig{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("jobconfigs").
		Name(jobConfig.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(jobConfig).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the jobConfig and deletes it. Returns an error if one occurs.
func (c *jobConfigs) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("jobconfigs").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *jobConfigs) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("jobconfigs").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched jobConfig.
func (c *jobConfigs) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.JobConfig, err error) {
	result = &v1alpha1.JobConfig{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("jobconfigs").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
